@@ -12,7 +12,7 @@ STATS[["mean.diffs"]] <- {list(
     threshold = "m.threshold",
     Threshold = "M.Threshold",
     disp_stat = "disp.diff",
-    bin_only = FALSE,
+    adj_only = FALSE,
     abs = function(x) abs_(x),
     bal.tab_column_prefix = "Diff", #Also which.stat in love.plot
     threshold_range = c(0, Inf),
@@ -110,7 +110,7 @@ STATS[["variance.ratios"]] <- {list(
     threshold = "v.threshold",
     Threshold = "V.Threshold",
     disp_stat = "disp.v.ratio",
-    bin_only = TRUE,
+    adj_only = FALSE,
     abs = function(x) abs_(x, ratio = TRUE),
     bal.tab_column_prefix = "V.Ratio", #Also which.stat in love.plot
     threshold_range = c(1, Inf),
@@ -145,7 +145,7 @@ STATS[["ks.statistics"]] <- {list(
     threshold = "ks.threshold",
     Threshold = "KS.Threshold",
     disp_stat = "disp.ks",
-    bin_only = FALSE,
+    adj_only = FALSE,
     abs = function(x) abs_(x),
     bal.tab_column_prefix = "KS", #Also which.stat in love.plot
     threshold_range = c(0, 1),
@@ -174,7 +174,7 @@ STATS[["ovl.coefficients"]] <- {list(
     threshold = "ovl.threshold",
     Threshold = "OVL.Threshold",
     disp_stat = "disp.ovl",
-    bin_only = FALSE,
+    adj_only = FALSE,
     abs = function(x) abs_(x),
     bal.tab_column_prefix = "OVL", #Also which.stat in love.plot
     threshold_range = c(0, 1),
@@ -203,7 +203,7 @@ STATS[["correlations"]] <- {list(
     threshold = "r.threshold",
     Threshold = "R.Threshold",
     disp_stat = "disp.corr",
-    bin_only = FALSE,
+    adj_only = FALSE,
     abs = function(x) abs_(x),
     bal.tab_column_prefix = "Corr", #Also which.stat in love.plot
     threshold_range = c(0, 1),
@@ -238,7 +238,7 @@ STATS[["spearman.correlations"]] <- {list(
     threshold = "s.threshold",
     Threshold = "S.Threshold",
     disp_stat = "disp.spear",
-    bin_only = FALSE,
+    adj_only = FALSE,
     abs = function(x) abs_(x),
     bal.tab_column_prefix = "S.Corr", #Also which.stat in love.plot
     threshold_range = c(0, 1),
@@ -268,10 +268,157 @@ STATS[["spearman.correlations"]] <- {list(
     }
 )}
 
+STATS[["mean.diffs.target"]] <- {list(
+    type = "cont",
+    threshold = "m.threshold",
+    Threshold = "M.Threshold",
+    disp_stat = "disp.diff",
+    adj_only = TRUE,
+    abs = function(x) abs_(x),
+    bal.tab_column_prefix = "Diff", #Also which.stat in love.plot
+    threshold_range = c(0, Inf),
+    balance_tally_for = "target mean differences",
+    variable_with_the_greatest = "target mean difference", #also which.stat2 in love.plot
+    love.plot_xlab = function(...) {
+        A <- list(...)
+        binary <- A$binary #attr(x, "print.options")$binary
+        continuous <- A$continuous #attr(x, "print.options")$continuous
+        abs <- A$abs
+        var_type <- A$var_type #B[["type"]]
+        stars <- A$stars
+        
+        #All std, no std, some std
+        if ((binary == "std" || !any(var_type == "Binary")) && 
+            (continuous == "std" || !any(var_type == "Contin."))) {
+            xlab.diff <- "Standardized Target Mean Differences"
+        } 
+        else if ((binary == "raw" || !any(var_type == "Binary")) && 
+                 (continuous == "raw" || !any(var_type == "Contin."))) {
+            xlab.diff <- "Target Mean Differences"
+        }
+        else {
+            stars <- match_arg(stars, c("none", "std", "raw"))
+            if (stars == "none") {
+                xlab.diff <- "Target Mean Differences"
+            }
+            else if (stars == "std") {
+                xlab.diff <- "Target Mean Differences"
+            }
+            else if (stars == "raw") {
+                xlab.diff <- "Standardized Target Mean Differences"
+            }
+        }
+        
+        xlab <- if (abs) paste("Absolute", xlab.diff) else xlab.diff
+        return(xlab)
+    },
+    love.plot_add_stars = function(SS.var, variable.names, ...) {
+        A <- list(...)
+        binary <- A$binary #attr(x, "print.options")$binary
+        continuous <- A$continuous #attr(x, "print.options")$continuous
+        var_type <- A$var_type #B[["Type"]]
+        stars <- A$stars
+        star_char = A$star_char #args$star_char
+        
+        #All std, no std, some std
+        if (!((binary == "std" || sum(var_type == "Binary") == 0) && 
+              (continuous == "std" || sum(var_type != "Binary") == 0)) 
+            &&
+            !((binary == "raw" || sum(var_type == "Binary") == 0) && 
+              (continuous == "raw" || sum(var_type != "Binary") == 0))) {
+            
+            stars <- match_arg(stars, c("none", "std", "raw"))
+            if (stars == "none") {
+                warning("Standardized mean differences and raw mean differences are present in the same plot. \nUse the 'stars' argument to distinguish between them and appropriately label the x-axis.", call. = FALSE)
+            }
+            else {
+                if (!rlang::is_string(star_char)) star_char <- "*"
+                
+                vars_to_star <- setNames(rep(FALSE, length(variable.names)), variable.names)
+                if (stars == "std") {
+                    if (binary == "std") vars_to_star[variable.names[var_type == "Binary"]] <- TRUE
+                    if (continuous == "std") vars_to_star[variable.names[var_type != "Binary"]] <- TRUE
+                }
+                else if (stars == "raw") {
+                    if (binary == "raw") vars_to_star[variable.names[var_type == "Binary"]] <- TRUE
+                    if (continuous == "raw") vars_to_star[variable.names[var_type != "Binary"]] <- TRUE
+                }
+                new.variable.names <- setNames(variable.names, variable.names)
+                names(new.variable.names)[vars_to_star[variable.names]] <- paste0(variable.names[vars_to_star[variable.names]], star_char)
+                SS.var <- do.call(f.recode, c(list(SS.var), new.variable.names))
+            }
+        }
+        
+        return(SS.var)
+    },
+    baseline.xintercept = 0,
+    threshold.xintercepts = function(threshold, abs) {
+        if (abs) c(lower = base::abs(threshold))
+        else c(lower = -base::abs(threshold), upper = base::abs(threshold))
+    },
+    love.plot_axis_scale = ggplot2::scale_x_continuous,
+    fun = function(C, treat, weights, std, s.d.denom, abs, s.weights, bin.vars, weighted.weights = weights, subset = NULL, ...) {
+        n <- nrow(C)
+        C <- rbind(C, C)
+        treat <- rep(c(0,1), each = n)
+        if (is_not_null(weights)) weights <- c(weights, rep(1, n))
+        if (is_not_null(s.weights)) s.weights <- c(s.weights, s.weights)
+        if (is_not_null(subset)) subset <- c(subset, subset)
+        s.d.denom <- "1"
+        
+        if (is_not_null(weights)) {
+        col_w_smd(C, treat = treat, weights = weights, 
+                  std = std, s.d.denom = s.d.denom,
+                  abs = abs, s.weights = s.weights, bin.vars = bin.vars,
+                  weighted.weights = weighted.weights,
+                  subset = subset)
+        }
+        else rep(NA_real_, ncol(C))
+    }
+)}
+
+STATS[["ks.statistics.target"]] <- {list(
+    type = "cont",
+    threshold = "ks.threshold",
+    Threshold = "KS.Threshold",
+    disp_stat = "disp.ks",
+    adj_only = TRUE,
+    abs = function(x) abs_(x),
+    bal.tab_column_prefix = "KS", #Also which.stat in love.plot
+    threshold_range = c(0, 1),
+    balance_tally_for = "target KS statistics",
+    variable_with_the_greatest = "target KS statistic", #also which.stat2 in love.plot
+    love.plot_xlab = function(...) {
+        "Target Kolmogorov-Smirnov Statistics"
+    },
+    love.plot_add_stars = function(SS.var, variable.names, ...) {
+        return(SS.var)
+    },
+    baseline.xintercept = 0,
+    threshold.xintercepts = function(threshold, abs) {
+        c(lower = base::abs(threshold))
+    },
+    love.plot_axis_scale = ggplot2::scale_x_continuous,
+    fun = function(C, treat, weights, s.weights, bin.vars, subset = NULL, ...) {
+        A <- list(...)
+        
+        n <- nrow(C)
+        C <- rbind(C, C)
+        treat <- rep(c(0,1), each = n)
+        if (is_not_null(weights)) weights <- c(weights, rep(1, n))
+        if (is_not_null(s.weights)) s.weights <- c(s.weights, s.weights)
+        if (is_not_null(subset)) subset <- c(subset, subset)
+        
+        do.call("col_w_ks", c(list(C, treat = treat, weights = weights, s.weights = s.weights, bin.vars = bin.vars,
+                                   subset = subset), A))
+    }
+)}
+
 all_STATS <- function(type) {
-    if (missing(type)) names(STATS)
+    if (missing(type)) out <- names(STATS)
     else {
         type <- match_arg(type, c("bin", "cont"))
-        names(STATS)[get_from_STATS("type") == type]
+        out <- names(STATS)[get_from_STATS("type") == type]
     }
-}
\ No newline at end of file
+    unique(out)
+}
