@@ -11,7 +11,7 @@ f.build <- function(y, rhs) {
     tryCatch(force(y), error = function(e) stop(conditionMessage(e), call. = FALSE))
     tryCatch(force(rhs), error = function(e) stop(conditionMessage(e), call. = FALSE))
     
-    if (is_(rhs, c("matrix", "data.frame")) && is_not_null(colnames(rhs))) {
+    if (is_mat_like(rhs) && is_not_null(colnames(rhs))) {
         vars <- paste0("`", gsub("`", "", colnames(rhs)), "`")
     }
     else if (is_(rhs, "character")) {
