@@ -1,5 +1,6 @@
 ## ---- include = FALSE---------------------------------------------------------
 knitr::opts_chunk$set(message = FALSE, fig.width=5)
+if (any(!sapply(c("WeightIt", "twang"), requireNamespace, quietly = TRUE))) knitr::opts_chunk$set(eval = FALSE)
 
 ## -----------------------------------------------------------------------------
 library("cobalt")
@@ -7,12 +8,12 @@ data("iptwExWide", package = "twang")
 head(iptwExWide)
 
 ## -----------------------------------------------------------------------------
-library("WeightIt")
-Wmsm <- weightitMSM(list(tx1 ~ use0 + gender + age,
-                         tx2 ~ use0 + gender + age + use1 + tx1,
-                         tx3 ~ use0 + gender + age + use1 + tx1 + use2 + tx2),
-                    data = iptwExWide,
-                    method = "ps")
+Wmsm <- WeightIt::weightitMSM(
+    list(tx1 ~ use0 + gender + age,
+         tx2 ~ use0 + gender + age + use1 + tx1,
+         tx3 ~ use0 + gender + age + use1 + tx1 + use2 + tx2),
+    data = iptwExWide,
+    method = "ps")
 
 ## -----------------------------------------------------------------------------
 bal.tab(list(iptwExWide[c("use0", "gender", "age")],
